==> dev-plugin-android-6.1.9-beta1-sources.jar: com/zoyi/channel/plugin/android/model/rest/Channel.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.model.entity.Entity;
import com.zoyi.channel.plugin.android.model.entity.ProfileEntity;
import com.zoyi.channel.plugin.android.util.ResUtils;
import com.zoyi.channel.plugin.android.util.TimeUtils;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Channel implements Entity, ProfileEntity {

  public static final String EXPECTED_RESPONSE_DELAY_INSTANT = "instant";
  public static final String EXPECTED_RESPONSE_DELAY_NORMAL = "normal";
  public static final String EXPECTED_RESPONSE_DELAY_DELAYED = "delayed";

  public static final String PLAN_PRO = "pro";

  private String id;
  private String name;
  private String domain;
  private String description;
  private String timeZone;
  private WorkingTime workingTime;
  private TimeRange lunchTime;
  private String homepageUrl;
  private String phoneNumber;
  private String messengerPlan;
  private String pushBotPlan;
  private String supportBotPlan;
  private Boolean blocked;
  private Boolean requestGuestInfo;
  private String expectedResponseDelay;
  private String workingType;
  private String awayOption;
  private Boolean trial;
  private String avatarUrl;
  private String utcOffset;
  private String defaultPluginId;

  @Override
  public String getId() {
    return id;
  }

  @NonNull
  @Override
  public String getName() {
    return name != null ? name : "";
  }

  public String getDomain() {
    return domain;
  }

  public String getDescription() {
    return description;
  }

  public String getAwayOption() {
    return awayOption;
  }

  public String getWorkingType() {
    return workingType;
  }

  @Override
  public String getAvatarUrl() {
    return avatarUrl;
  }

  public final static String CLASSNAME = "Channel";

  public String getWorkingTimeText(Context context) {
    String launch = lunchTime != null
        ? String.format(
        "%s: %s",
        ResUtils.getString(context, "ch.out_of_work.lunch_time"),
        TimeUtils.getTimeRangeString(lunchTime))
        : null;

    if (workingTime != null) {
      String work = workingTime.getMessage(context);
      if (launch != null) {
        return String.format("Timezone: %s\n\n%s\n\n%s", timeZone, work, launch);
      }
      return String.format("Timezone: %s\n\n%s", timeZone, work);
    }
    return "";
  }

  @Nullable
  public WorkingTime getWorkingTime() {
    if (Const.WORKING_TYPE_CUSTOM.equals(workingType)) {
      return workingTime;
    }
    return null;
  }

  public TimeRange getLunchTime() {
    return lunchTime;
  }

  public long getUtcOffsetMinutes() {
    try {
      String[] split = utcOffset.split(":");

      long hours = Long.valueOf(split[0]);
      long minutes = Long.valueOf(split[1]);
      int sign = hours < 0 ? -1 : 1;

      return (hours * sign * 60 + minutes) * sign;
    } catch (Exception ignored) {
    }
    return 0;
  }

  public String getHomepageUrl() {
    return homepageUrl;
  }

  public String getPhoneNumber() {
    return phoneNumber;
  }

  public String getMessengerPlan() {
    return messengerPlan;
  }

  public String getPushBotPlan() {
    return pushBotPlan;
  }

  public String getSupportBotPlan() {
    return supportBotPlan;
  }

  public boolean isRequestGuestInfo() {
    return requestGuestInfo;
  }

  public String getExpectedResponseDelay() {
    return expectedResponseDelay;
  }

  public boolean isTrial() {
    if (trial == null) {
      return false;
    }
    return trial;
  }

  public boolean isProMessengerPlan() {
    return PLAN_PRO.equals(getMessengerPlan());
  }

  public boolean canUseMobileSdk() {
    return !blocked && (isTrial() || isProMessengerPlan());
  }

  public String getDefaultPluginId() {
    return defaultPluginId;
  }
}

==> dev-plugin-android-9.0.0+beta1-sources.jar: com/zoyi/channel/plugin/android/model/rest/Channel.java <==
package com.zoyi.channel.plugin.android.model.rest;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import android.text.TextUtils;

import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.model.entity.Entity;
import com.zoyi.channel.plugin.android.model.entity.ProfileEntity;
import com.zoyi.com.annimon.stream.Stream;

import java.util.List;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Channel implements Entity, ProfileEntity {

  public static final String EXPECTED_RESPONSE_DELAY_INSTANT = "instant";
  public static final String EXPECTED_RESPONSE_DELAY_NORMAL = "normal";
  public static final String EXPECTED_RESPONSE_DELAY_DELAYED = "delayed";

  public static final String PLAN_PRO = "pro";

  private String id;
  private String name;
  @Nullable
  private String domain;
  @Nullable
  private String description;
  @Nullable
  private String timeZone;
  @Nullable
  private List<TimeRange> workingTimeRanges;
  @Nullable
  private String homepageUrl;
  @Nullable
  private String phoneNumber;
  @Nullable
  private String expectedResponseDelay;
  @Nullable
  private String workingType;
  @Nullable
  private String awayOption;
  @Nullable
  private String avatarUrl;
  @Nullable
  private String utcOffset;
  @Nullable
  private String defaultPluginId;
  @Nullable
  private Boolean whiteLabelFeature;

  @Override
  public String getId() {
    return id;
  }

  @NonNull
  @Override
  public String getName() {
    return name != null ? name : "";
  }

  @Nullable
  public String getDomain() {
    return domain;
  }

  @Nullable
  public String getDescription() {
    return description;
  }

  @Nullable
  public String getAwayOption() {
    return awayOption;
  }

  @Nullable
  public String getWorkingType() {
    return workingType;
  }

  @Nullable
  @Override
  public String getAvatarUrl() {
    return avatarUrl;
  }

  public final static String CLASSNAME = "channel";

  public String getWorkingTimeText() {
    if (workingTimeRanges != null) {
      String work = TextUtils.join(
          "\n",
          Stream.ofNullable(workingTimeRanges).map(TimeRange::getMessage).toList()
      );
      return String.format("%s\n\nTimezone: %s", work, timeZone);
    }
    return "";
  }

  @Nullable
  public List<TimeRange> getWorkingTimeRanges() {
    if (Const.WORKING_TYPE_CUSTOM.equals(workingType) && hasValidWorkingTime()) {
      return workingTimeRanges;
    }
    return null;
  }

  public boolean hasValidWorkingTime() {
    if (!Const.WORKING_TYPE_CUSTOM.equals(workingType)) {
      return false;
    }

    if (workingTimeRanges == null) {
      return false;
    }

    return Stream.ofNullable(workingTimeRanges)
        .filter(TimeRange::isValid)
        .count() > 0;
  }

  public long getUtcOffsetMinutes() {
    try {
      if (utcOffset != null) {
        String[] split = utcOffset.split(":");

        long hours = Long.valueOf(split[0]);
        long minutes = Long.valueOf(split[1]);
        int sign = hours < 0 ? -1 : 1;

        return (hours * sign * 60 + minutes) * sign;
      }
    } catch (Exception ignored) {
    }
    return 0;
  }

  @Nullable
  public String getHomepageUrl() {
    return homepageUrl;
  }

  @Nullable
  public String getPhoneNumber() {
    return phoneNumber;
  }

  @Nullable
  public String getExpectedResponseDelay() {
    return expectedResponseDelay;
  }

  @Nullable
  public String getDefaultPluginId() {
    return defaultPluginId;
  }

  public boolean isWhiteLabelFeature() {
    if (whiteLabelFeature == null) {
      return false;
    }
    return whiteLabelFeature;
  }
}
